# I Use This

A while back, I published a post about my setup, inspired by the awesome articles on the UsesThis site.

As times change, so does my toolset. So, here's a list of my latest favorite things. I love them, and think you should use them too.

## ep.io

Perfectly Pythonic WSGI Hosting.

There are a number of new Heroku-like Python hosts out there, but most of them leave a bad taste in my mouth. This is mostly because they only support Django, and not generic WSGI (e.g. Flask apps).

Ep.io supports any WSGI application. It charges based on usage and offers a generous amount of free usage per application. Redis support. Cron jobs. Optional git/mercurial integration. The architecture and configurations are very elegant. I love it.

I host a most of my open source applications, including this very website, on ep.io. I couldn't be happier.

[ ep.io ]

## gaug.es

Google Analytics is an extremely power analytics platform that can be used to drive important business decisions and analyze deep trends.

I don't need any of that.

I need realtime traffic information, visitor browsers and devices, and a simple list of referral URLs.

Check out Gauges. Realtime, simple, and elegant analytics. No domain limits. It's provided by a group of great guys that are passionate about making the service as awesome as possible. It really shows.

[ gaug.es ]

## DNSimple

Stop using GoDaddy. Now. They have extremely misleading billing practices, terrible ads, and — worst of all — one of the worst DNS management interfaces on earth.

DNSimple has the simplest and most elegant DNS management system I've ever used. Everything just works — instantly. One-click record templates for GitHub Pages, Google Apps, etc.

There's a small subscription fee, tiered by the number of hosted domains. If you find yourself thinking, "Why would I pay for DNS hosting?": You get what you pay for.

It doesn't matter where you register your domains, but I register all of mine through DNSimple. The registration cost is a little high compared to a few providers, but — again — you really get what you pay for.

I got a signed postcard from them in the mail last year, wishing me a Happy New Year. These guys care.

[ DNSimple ]

## Sublime Text 2

It's time to face the facts: TextMate is dead. The author has been lying to his loyal community for a long time now. It's time for us to move on.

I looked for a worthy replacement for a long time. This wasn't an easy task. I believe that I have tried literally every editor ever released for every major operating system within the past 10 years. I'm really picky about my development environment; It's part of who I am.

Sublime Text 2 is incredible.

It offers TextMate theme and snippets support, extremely optimized workflows, and a full internal Python API for writing plugins. Coupled with SublimeLint and Soda Theme Dark, it's perfect.

It's available for OS X, Linux, and Windows too.

[ Sublime Text 2 ]

## Readability

Full disclosure: I work for Readability. However, that's completely irrelevant. Readability is easily one of my favorite tools ever.

If I land on an article that's either ugly or too long to read at the moment, I hit ` in Chrome. I'm presented with a highly polished, content-only version of the article with elegant typography.

Top notch browser plugins. First-class Typography. Offline HTML5 apps for every device I own. A daily digest of my articles, sent to my Kindle automatically? Yes, please.

[ Readability ]

## Canon 35mm f/1.4L

One of the few things that gets me away from my machine is photography. Check out my Flickr stream. It's very much a hobby, but I quite enjoy it.

My lens kit has gone through quite a few iterations. It took me a while, but I'm finally got rid of my last zoom lens, and have moved on to all primes. Zooms seem to suck creativity out of me. Constraints are good.

My new favorite lens is the Canon EF 35mm f/1.4L. I'm blown away by this thing. It's exactly what I've been looking for. I can't believe it hasn't been updated since 1992.

I've noticed a bit of a fanastic subculture behind this lens since I got it. If you ever take a look at the White House's Flickr Stream, you'll see the excellent work of Pete Souza. He uses the 35L in almost every indoor photo. Incredible.

Before, I typically shot with my moderately telephoto 85mm f/1.2L (my photon vaccuum). I still use it on certain occasions, but the 35L is really bringing my photography to a new level.

The 35L & 85L are an unstoppable duo.

## WebFaction

I've never been a fan of shared hosting at all. These guys proved me wrong.

They really know their stuff. Python is a true first-class citizen on their boxes: 2.4, 2.5, 2.6, 2.7, 3.1, 3.2 are all available, with most of the popular supporting libraries (PIL, etc), out of the box. One click installers for WordPress and more with 100% perfect permissions set. Nginx-fronted Apache, giving you the best of both worlds. A standard account gets you user-level SSH access to the box. Awesome.

If I need to host a PHP or static app, they're my first stop.

[ WebFaction ]

## Read the Docs

A product of last year's DjangoDash, Read the Docs is the best Sphinx documentation site around. It's open source too.

python-requests.org, python-guide.org, and tablib.org are all hosted on RTD. You should use it too.

[ Read the Docs ]

## Bonus Things

- Binary Pandoc Installer for OSX
- Xcode-less GCC Installer for OSX

## blogroll

- About
- Resume

## social

- atom feed
- GitHub
- Twitter